@@ -2,8 +2,8 @@
 
 set -eu
 
-last_version=1.2
-new_version=1.3
+last_version=1.3
+new_version=1.4
 last_version_file=pglogical_ticker--${last_version}.sql
 new_version_file=pglogical_ticker--${new_version}.sql
 update_file=pglogical_ticker--${last_version}--${new_version}.sql
@@ -33,9 +33,10 @@ d=$2
 (cat "${s}"; echo; echo) >> "$d"
 }
 
-#create_update_file_with_header
+create_update_file_with_header
 
 # Add view and function changes
+add_file functions/pglogical_ticker.launch.sql $update_file
 
 # Only copy diff and new files after last version, and add the update script
 touch $update_file
